DICOM Standard Parser
=====================

The DICOM Standard in JSON format, parsed from the web version of the standard
using a collection of extensible python scripts.

- View the `JSON here
  <https://www.github.com/innolitics/dicom-standard/standard>`_.

- View the `documentation here
  <https://www.github.com/innolitics/dicom-standard/docs/index.md>`_.
